;Include Modern UI

  !include "MUI.nsh"

;Seleccionamos el algoritmo de compresin utilizado para comprimir nuestra aplicacin
SetCompressor lzma


;--------------------------------
;Con esta opcion alertamos al usuario y le pedimos confirmacin para abortar
;la instalacin
;Esta macro debe colocarse en esta posicin del script sino no funcionara
  !define mui_abortwarning

;Definimos el valor de la variable VERSION, en caso de no definirse en el script
;podria ser definida en el compilador
!define VERSION "1.0"


;--------------------------------
;Pages

  ;Mostramos la pgina de bienvenida
  !insertmacro MUI_PAGE_WELCOME
  ;Pgina donde mostramos el contrato de licencia 
  !insertmacro MUI_PAGE_LICENSE "licencia.txt"
  ;pgina donde se muestran las distintas secciones definidas
  !insertmacro MUI_PAGE_COMPONENTS
  ;pgina donde se selecciona el directorio donde instalar nuestra aplicacion
  !insertmacro MUI_PAGE_DIRECTORY
  ;pgina de instalacin de ficheros
  !insertmacro MUI_PAGE_INSTFILES
  ;pgina final
  !insertmacro MUI_PAGE_FINISH
  
;pginas referentes al desinstalador
  !insertmacro MUI_UNPAGE_WELCOME
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  !insertmacro MUI_UNPAGE_FINISH
  
;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "Spanish"

; Para generar instaladores en diferentes idiomas podemos escribir lo siguiente:
;  !insertmacro MUI_LANGUAGE ${LANGUAGE}
; De esta forma pasando la variable LANGUAGE al compilador podremos generar
;paquetes en distintos idiomas sin cambiar el script

;;;;;;;;;;;;;;;;;;;;;;;;;
; Configuration General ;
;;;;;;;;;;;;;;;;;;;;;;;;;
;Nuestro instalador se llamara si la version fuera la 1.0: UhuPoly-1.0-win32.exe
OutFile UhuPoly-${VERSION}-win32.exe

;Aqui comprobamos que en la versin Inglesa se muestra correctamente el mensaje:
;Welcome to the $Name Setup Wizard
;Al tener reservado un espacio fijo para este mensaje, y al ser
;la frase en espaol mas larga:
; Bienvenido al Asistente de Instalacin de Aplicacin $Name
; no se ve el contenido de la variable $Name si el tamao es muy grande
Name "UhuPoly"
Caption "UhuPoly ${VERSION} para Win32 Setup"
;Icon icono.ico

;Comprobacion de integridad del fichero activada
CRCCheck on
;Estilos visuales del XP activados
XPStyle on

/*
	Declaracion de variables a usar
	
*/
# tambin comprobamos los distintos
; tipos de comentarios que nos permite este lenguaje de script

Var PATH
Var PATH_ACCESO_DIRECTO
;Indicamos cual sera el directorio por defecto donde instalaremos nuestra
;aplicacin, el usuario puede cambiar este valor en tiempo de ejecucin.
InstallDir "$PROGRAMFILES\UhuPoly"

; check if the program has already been installed, if so, take this dir
; as install dir
InstallDirRegKey HKLM SOFTWARE\UhuPoly "Install_Dir"
;Mensaje que mostraremos para indicarle al usuario que seleccione un directorio
DirText "Elija un directorio donde instalar la aplicacin:"

;Indicamos que cuando la instalacin se complete no se cierre el instalador automticamente
AutoCloseWindow false
;Mostramos todos los detalles del la instalacin al usuario.
ShowInstDetails show
;En caso de encontrarse los ficheros se sobreescriben
SetOverwrite on
;Optimizamos nuestro paquete en tiempo de compilacin, es ltamente recomendable habilitar siempre esta opcin
SetDatablockOptimize on
;Habilitamos la compresin de nuestro instalador
SetCompress auto
;Personalizamos el mensaje de desinstalacin
UninstallText "Este es el desinstalador del UhuPoly."


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Install settings                                                    ;
; En esta seccin aadimos los ficheros que forman nuestra aplicacin ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Section "UhuPoly"
	StrCpy $PATH "UhuPoly"
	StrCpy $PATH_ACCESO_DIRECTO "UhuPoly"

	SetOutPath $INSTDIR\$PATH
;by Manel
; Se define la carpeta a incluir en el instalador

File /r "dist\"

;Incluimos todos los ficheros que componen nuestra aplicacin
	;File  uhupoly.exe
	;File  licencia.html
	;File  config.ini
	;File  *.txt

	;File  dist\lib\swing-layout-1.0.3.jar
	File  dist\mv_uhupoly_v02.jar

;Hacemos que la instalacin se realice para todos los usuarios del sistema
        SetShellVarContext all
;Creamos los directorios, acesos directos y claves del registro que queramos...
	CreateDirectory "$SMPROGRAMS\$PATH_ACCESO_DIRECTO"
	CreateShortCut "$SMPROGRAMS\$PATH_ACCESO_DIRECTO\UhuPoly.lnk" \
                       "$INSTDIR\$PATH_ACCESO_DIRECTO\mv_uhupoly_v02.jar" 
	CreateShortCut "$SMPROGRAMS\$PATH_ACCESO_DIRECTO\Manual_Usuario.lnk" \
                       "$INSTDIR\$PATH_ACCESO_DIRECTO\doc\manual_usuario.html"
	CreateShortCut "$SMPROGRAMS\$PATH_ACCESO_DIRECTO\Manual_instalacion.lnk" \
                       "$INSTDIR\$PATH_ACCESO_DIRECTO\doc\manual_instalacion.html"

;Creamos tambin el aceso directo al instalador
	CreateShortCut "$SMPROGRAMS\$PATH_ACCESO_DIRECTO\Desinstalar.lnk" \
                       "$INSTDIR\uninstall.exe"

        WriteRegStr HKLM \
            SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\$PATH \
            "DisplayName" "Aplicacin UhuPoly microvenus ${VERSION}"
        WriteRegStr HKLM \
            SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\$PATH \
            "UninstallString" '"$INSTDIR\uninstall.exe"'
	WriteUninstaller "uninstall.exe"

	WriteRegStr HKLM SOFTWARE\$PATH "InstallDir" $INSTDIR
	WriteRegStr HKLM SOFTWARE\$PATH "Version" "${VERSION}"

	Exec "explorer $SMPROGRAMS\$PATH_ACCESO_DIRECTO\"
SectionEnd

/*
Section "Ayuda"
	SetOutPath $INSTDIR\$PATH
	StrCpy $PATH "UhuPoly"
	StrCpy $PATH_ACCESO_DIRECTO "UhuPoly"
;Estos directorios han de contener algn fichero, sino el compilador
;dara el error: File: "ayuda" -> no files found.
;En caso de querer que nuestra aplicacin se creen directorios vacios una opcin
;es crear un fichero dummy.txt
	File  /r ayuda
SectionEnd

Section "Skins"
	SetOutPath $INSTDIR\$PATH
	StrCpy $PATH "UhuPoly"
	StrCpy $PATH_ACCESO_DIRECTO "UhuPoly"
	File  /r skins
SectionEnd

Section "Plugins"
	SetOutPath $INSTDIR\$PATH
	StrCpy $PATH "UhuPoly"
	StrCpy $PATH_ACCESO_DIRECTO "UhuPoly"
	File  /r plugins
SectionEnd
*/
;;;;;;;;;;;;;;;;;;;;;;
; Uninstall settings ;
;;;;;;;;;;;;;;;;;;;;;;

Section "Uninstall"
	StrCpy $PATH "UhuPoly"
	StrCpy $PATH_ACCESO_DIRECTO "UhuPoly"
        SetShellVarContext all
	RMDir /r $SMPROGRAMS\$PATH_ACCESO_DIRECTO
	RMDir /r $INSTDIR\$PATH
	RMDir /r $INSTDIR
	DeleteRegKey HKLM SOFTWARE\$PATH
        DeleteRegKey HKLM \
            Software\Microsoft\Windows\CurrentVersion\Uninstall\$PATH
SectionEnd
